#!/usr/bin/env python3

import importlib.util
import os
import os.path
import shutil
import subprocess
import sys

this_dir = os.path.abspath(os.path.dirname(__file__) or ".")

def version(build_it):
    return "1.7.1"

def install(build_it):
    zip_ = "libgeotiff-1.7.1.tar.gz"
    src_dir = "libgeotiff-1.7.1"
    if os.path.isdir(src_dir):
        shutil.rmtree(src_dir)
    build_it.extract_file(zip_)
    os.chdir(src_dir)
    patch_dir = os.path.join(this_dir, "patches")
    with open(os.path.join(patch_dir, "geotiff_proj4.c.patch"), 'r') as patch_h:
        subprocess.check_call(["patch", "-b", "-p0"], stdin=patch_h)
    subprocess.check_call(["./configure", "--prefix", build_it.opt_dir])
    subprocess.check_call(["make"])
    #subprocess.check_call(["make", "test"])
    subprocess.check_call(["make", "install"])

    os.chdir(this_dir)

    if not os.environ['OCSSW_DEBUG'] or os.environ['OCSSW_DEBUG'] == "0":
        shutil.rmtree(src_dir)

if __name__ == "__main__":
    os.chdir(this_dir)

    spec = importlib.util.spec_from_file_location("BuildIt", os.path.join("..", "BuildIt.py"))
    build_it = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(build_it)
    master = build_it.BuildIt()
    master.setup_environment()
    sys.exit(install(master))
